"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var validatorz_1 = require("./validatorz");
exports.createStringValidator = validatorz_1.createStringValidator;
exports.createNumberValidator = validatorz_1.createNumberValidator;
exports.createOneOfValidator = validatorz_1.createOneOfValidator;
var validatorz_2 = require("./validatorz");
exports.validateName = validatorz_2.createStringValidator({
    min: 1,
    max: 40,
    validChars: ["letters", "., "],
});
exports.validateAge = validatorz_2.createNumberValidator({
    min: 0,
    max: 120,
});
exports.validateUsername = validatorz_2.createStringValidator({
    min: 3,
    max: 40,
    validChars: ["letters", "digits", "_-"]
});
exports.validatePhone = validatorz_2.createStringValidator({
    min: 10,
    max: 10,
    validChars: ["digits"],
});
exports.validatePassword = validatorz_2.createStringValidator({
    mustContain: ["digits", "lowercase", "uppercase", "symbols"],
    min: 8,
    max: 100,
});
exports.validateEmail = validatorz_2.createStringValidator({
    regexp: "^(([^<>()[\\]\\\\.,;:\\s@\"]+(\\.[^<>()[\\]\\\\.,;:\\s@\"]+)*)|(\".+\"))@((\\[[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}])|(([a-zA-Z\\-0-9]+\\.)+[a-zA-Z]{2,}))$",
});
exports.validateEIN = validatorz_2.createStringValidator({
    regexp: "^[1-9]\\d?-\\d{7}$",
});
exports.validateDOB = (function () {
    var min = new Date(1900, 1, 0);
    return function (date) {
        if (!(date instanceof Date)) {
            try {
                date = new Date(date);
            }
            catch (e) {
                return ["Could not convert " + date + " into a date"];
            }
        }
        if (date < min) {
            return ["Date of birth cannot be before January 1, 1900"];
        }
        if (date > new Date) {
            return ["Date of birth cannot be in the future."];
        }
        return [];
    };
})();
//# sourceMappingURL=index.js.map