export interface IValidatorsNumberRequirements {
    min?: number;
    max?: number;
}
export interface IValidatorsStringRequirements {
    mustContain?: string[] | string;
    validChars?: string[] | string;
    min?: number | Number;
    max?: number;
    regexp?: RegExp | string;
    number?: IValidatorsNumberRequirements;
}
export declare type IValidatorsPresets = {
    dob: IValidatorsRequirements;
    name: IValidatorsRequirements;
    ein: IValidatorsRequirements;
    password: IValidatorsRequirements;
    age: IValidatorsRequirements;
    email: IValidatorsRequirements;
    username: IValidatorsRequirements;
    phone: IValidatorsRequirements;
};
export declare type IValidatorsRequirements = IValidatorsNumberRequirements | IValidatorsStringRequirements | ValidatorCreator;
export declare type IValidatorsValidateOptions = {
    maxErrors?: number;
};
export declare type Validator = NumberValidator | StringValidator;
export declare type NumberValidator = NumberValidatorFn | NumberValidatorInterface;
export declare type StringValidator = StringValidatorFn | StringValidatorInterface;
export declare type StringValidatorFn = (str: string) => string[];
export interface StringValidatorInterface {
    (str: string): string[];
    required: StringValidatorFn;
}
export declare type NumberValidatorFn = (num: number) => string[];
export declare type ValidatorCreator = () => (val: any) => string[];
export declare const charHashes: {
    letters: any;
    lowercase: any;
    uppercase: any;
    digits: any;
    symbols: any;
    alphanumeric: any;
    spaces: any;
};
export declare const getHash: (str: any) => any;
export declare const combineHashes: (...hashes: any[]) => any;
export declare const createBinaryHash: (acc: any, cur: any, idx: any) => any;
export declare const surroundQuotes: (str: any) => string;
export declare const createMustContainValidator: (mustContain: any) => StringValidatorFn;
export declare const createStringMinValidator: (min: any) => StringValidatorFn;
export declare const createStringMaxValidator: (max: any) => StringValidatorFn;
export declare const createValidCharsValidator: (validChars: any) => StringValidatorFn;
export declare const createRegexpValidator: (regexp: any) => StringValidatorFn;
export declare const createStringValidator: (requirements: IValidatorsStringRequirements) => StringValidatorInterface;
export interface NumberValidatorInterface {
    (num: number): string[];
    required: NumberValidatorFn;
}
export declare const createNumberValidator: ({ min, max }: IValidatorsNumberRequirements) => NumberValidatorInterface;
export declare const createOneOfValidator: ({ options }: {
    options: any[];
}) => {
    (input: any): string[];
    required(val: any): string[];
};
