"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var human_list_1 = require("human-list");
var alphabetLower = 'abcdefghijklmnopqrstuvwxyz';
var alphabetUpper = alphabetLower.toUpperCase();
var alphabetAll = alphabetLower + alphabetUpper;
var digits = '0123456789';
var alphanumeric = alphabetAll + digits;
var symbols = "!@#$%^&*()_-+=[{]}\\|><.,?/\"';:~`";
var charsToHash = function (chars) { return chars
    .split('')
    .reduce(function (prev, cur) {
    prev[cur] = true;
    return prev;
}, {}); };
exports.charHashes = {
    letters: charsToHash(alphabetAll),
    lowercase: charsToHash(alphabetLower),
    uppercase: charsToHash(alphabetUpper),
    digits: charsToHash(digits),
    symbols: charsToHash(symbols),
    alphanumeric: charsToHash(alphanumeric),
    spaces: charsToHash(" ")
};
exports.getHash = function (str) { return exports.charHashes[str] ? exports.charHashes[str] : charsToHash(str); };
exports.combineHashes = function () {
    var hashes = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        hashes[_i] = arguments[_i];
    }
    return hashes.reduce(function (prev, cur) { return (__assign(__assign({}, prev), exports.getHash(cur))); }, {});
};
var getHumanList = function (arr, conjunction) {
    if (conjunction === void 0) { conjunction = "and"; }
    return [arr.slice(0, -1).join(', '), arr.slice(-1)[0]]
        .join(arr.length < 2 ? '' : arr.length < 3 ? " " + conjunction + " " : ", " + conjunction + " ");
};
exports.createBinaryHash = function (acc, cur, idx) {
    var binaryRepresentation = (1 << idx);
    for (var char in cur) {
        acc[char] = (acc[char] || 0) | binaryRepresentation;
    }
    return acc;
};
exports.surroundQuotes = function (str) { return "\"" + str + "\""; };
exports.createMustContainValidator = function (mustContain) {
    var mustContainNames = [].concat(mustContain)
        .map(function (name) { return exports.charHashes[name] ? camelToLower(name) : name; });
    var binaryHash = mustContainNames
        .reverse()
        .map(exports.getHash)
        .reduce(exports.createBinaryHash, {});
    var checkVal = parseInt("1".repeat(mustContain.length), 2);
    return function (str) {
        var curVal = 0;
        for (var _i = 0, str_1 = str; _i < str_1.length; _i++) {
            var char = str_1[_i];
            if ((curVal |= binaryHash[char]) === checkVal) {
                return [];
            }
        }
        // not found, so retrieve names of missing values
        var notContained = [];
        for (var idx in mustContainNames) {
            if (!(curVal & 1)) {
                notContained.push(mustContainNames[idx]);
            }
            curVal >>= 1;
        }
        var humanList = getHumanList(notContained.map(exports.surroundQuotes));
        return ["Must contain " + humanList];
    };
};
exports.createStringMinValidator = function (min) { return function (str) {
    if (!str.length) {
        return ["Field is required."];
    }
    if (str.length < min) {
        return ["Must be at least " + min + " characters long."];
    }
}; };
exports.createStringMaxValidator = function (max) { return function (str) {
    if (str.length > max) {
        return ["Must be no longer than " + max + " characters long."];
    }
}; };
exports.createValidCharsValidator = function (validChars) {
    var validCharsArr = [].concat(validChars);
    var humanList = getHumanList(validCharsArr.map(exports.surroundQuotes));
    var errorMessageTail = " is not allowed. Only " + humanList + " are allowed.";
    var validCharsCombined = exports.combineHashes.apply(void 0, validCharsArr);
    return function (str) {
        for (var _i = 0, str_2 = str; _i < str_2.length; _i++) {
            var char = str_2[_i];
            if (!validCharsCombined[char]) {
                return [char + errorMessageTail];
            }
        }
        return [];
    };
};
exports.createRegexpValidator = function (regexp) { return function (str) {
    if (!regexp.test(str)) {
        return ["Invalid input."];
    }
}; };
var defaultValidateOptions = {
    maxErrors: Infinity,
};
exports.createStringValidator = function (requirements) {
    var validatorFns = [];
    if (requirements.mustContain) {
        validatorFns.push(exports.createMustContainValidator(requirements.mustContain));
    }
    if (requirements.validChars) {
        validatorFns.push(exports.createValidCharsValidator(requirements.validChars));
    }
    if (requirements.min) {
        validatorFns.push(exports.createStringMinValidator(requirements.min));
    }
    if (requirements.max) {
        validatorFns.push(exports.createStringMaxValidator(requirements.max));
    }
    if (requirements.regexp) {
        var regexp = requirements.regexp instanceof RegExp ? requirements.regexp : new RegExp(requirements.regexp);
        validatorFns.push(exports.createRegexpValidator(regexp));
    }
    var validator = function (str, options) {
        if (options === void 0) { options = defaultValidateOptions; }
        var errors = [];
        for (var _i = 0, validatorFns_1 = validatorFns; _i < validatorFns_1.length; _i++) {
            var validatorFn = validatorFns_1[_i];
            var newError = validatorFn(str);
            if (newError) {
                errors = errors.concat(newError);
                if (errors.length > options.maxErrors) {
                    break;
                }
            }
        }
        return errors;
    };
    validator.required = function (str, options) {
        if (options === void 0) { options = defaultValidateOptions; }
        if (str == null) {
            return ["Field is required."];
        }
        return validator(str, options);
    };
    return validator;
};
exports.createNumberValidator = function (_a) {
    var min = _a.min, max = _a.max;
    max = max || Infinity;
    min = min || -Infinity;
    var validator = function (num) {
        if (typeof num !== "number") {
            var originalNumber = num;
            num = Number(num);
            if (Number.isNaN(num)) {
                return ["Could not convert " + originalNumber + " to a number."];
            }
        }
        if (num < min) {
            return ["Must be greater than or equal to " + min + "."];
        }
        if (num > max) {
            return ["Must be less than or equal to " + max + "."];
        }
        return [];
    };
    validator.required = function (num) {
        if (num == null) {
            return ["Field is required."];
        }
        return validator(num);
    };
    return validator;
};
exports.createOneOfValidator = function (_a) {
    var options = _a.options;
    var err = ["Must be one of " + human_list_1.orList(options) + "."];
    var validator = function (input) {
        if (!options.includes(input)) {
            return err;
        }
        return [];
    };
    validator.required = function (val) {
        if (val == null) {
            return ["Field is required."];
        }
        return validator(val);
    };
    return validator;
};
function camelToLower(camelCase) {
    return camelCase
        .replace(/([A-Z])/g, function (match) { return " " + match; })
        .replace(/ ./g, function (match) { return match.toLowerCase(); })
        .trim();
}
//# sourceMappingURL=validatorz.js.map