export {
  createStringValidator, createNumberValidator, createOneOfValidator } from './validatorz'
export {
  Validator,
  StringValidator,
  NumberValidator,
  StringValidatorInterface,
  StringValidatorFn,
  NumberValidatorInterface,
  NumberValidatorFn,
} from './validatorz'
import { createStringValidator, createNumberValidator } from './validatorz'
import {
  Validator,
  StringValidator,
  NumberValidator,
  StringValidatorInterface,
  StringValidatorFn,
  NumberValidatorInterface,
  NumberValidatorFn,
} from './validatorz'


export const validateName: StringValidatorInterface = createStringValidator({
  min: 1,
  max: 40,
  validChars: ["letters", "., "],
})
export const validateAge: NumberValidatorInterface = createNumberValidator({
  min: 0,
  max: 120,
})
export const validateUsername:StringValidatorInterface = createStringValidator({
  min: 3,
  max: 40,
  validChars: ["letters", "digits", "_-"]
})
export const validatePhone: StringValidatorInterface = createStringValidator({
  min: 10,
  max: 10,
  validChars: ["digits"],
})
export const validatePassword: StringValidatorInterface = createStringValidator({
  mustContain: ["digits", "lowercase", "uppercase", "symbols"],
  min: 8,
  max: 100,
})
export const validateEmail: StringValidatorInterface = createStringValidator({
  regexp: "^(([^<>()[\\]\\\\.,;:\\s@\"]+(\\.[^<>()[\\]\\\\.,;:\\s@\"]+)*)|(\".+\"))@((\\[[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}])|(([a-zA-Z\\-0-9]+\\.)+[a-zA-Z]{2,}))$",
})
export const validateEIN: StringValidatorInterface = createStringValidator({
  regexp: "^[1-9]\\d?-\\d{7}$",
})

export const validateDOB = (() => {
  const min = new Date(1900, 1, 0)
  return (date: any) => {
    if (!(date instanceof Date)) {
      try {
        date = new Date(date)
      } catch (e) {
        return [`Could not convert ${date} into a date`]
      }
    }
    if (date < min) {
      return ["Date of birth cannot be before January 1, 1900"]
    }
    if (date > new Date) {
      return ["Date of birth cannot be in the future."]
    }
    return []
  }
})()